@@ -9,7 +9,7 @@ else:
     from typing import Final
 
 from unstructured.cleaners.core import remove_punctuation
-from unstructured.nlp.patterns import UNICODE_BULLETS_RE
+from unstructured.nlp.patterns import US_PHONE_NUMBERS_RE, UNICODE_BULLETS_RE
 from unstructured.nlp.tokenize import pos_tag, sent_tokenize, word_tokenize
 from unstructured.logger import logger
 
@@ -63,6 +63,16 @@ def is_bulleted_text(text: str) -> bool:
     return UNICODE_BULLETS_RE.match(text.strip()) is not None
 
 
+def contains_us_phone_number(text: str) -> bool:
+    """Checks to see if a section of text contains a US phone number.
+
+    Example
+    -------
+    contains_us_phone_number("867-5309") -> True
+    """
+    return US_PHONE_NUMBERS_RE.search(text.strip()) is not None
+
+
 def contains_verb(text: str) -> bool:
     """Use a POS tagger to check if a segment contains verbs. If the section does not have verbs,
     that indicates that it is not narrative text."""
